__all__ = ('ActionDescriptionPoint', 'NewUserActionPoint', 'FirstLoanActionPoint')

from expressmoney.api import *

SERVICE = 'partners'
APP = 'actions'


class ActionDescriptionReadContract(Contract):
    NEW_USER = 'NEW_USER'
    FIRST_LOAN = 'FIRST_LOAN'
    NAME_CHOICES = (
        (NEW_USER, NEW_USER),
        (FIRST_LOAN, FIRST_LOAN),
    )
    RU = 'RU'
    COUNTRY_CHOICES = (
        (RU, RU),
    )
    updated = serializers.DateTimeField()
    name = serializers.ChoiceField(choices=NAME_CHOICES)
    country = serializers.ChoiceField(choices=COUNTRY_CHOICES)
    amount = serializers.DecimalField(max_digits=16, decimal_places=0)


class NewUserActionCreateContract(Contract):
    pass


class NewUserActionReadContract(Contract):
    created = serializers.DateTimeField()
    referral = serializers.IntegerField(min_value=1)
    amount = serializers.DecimalField(max_digits=16, decimal_places=0)
    balance = serializers.DecimalField(max_digits=16, decimal_places=0)
    total = serializers.IntegerField(min_value=1)


class FirstLoanActionCreateContract(Contract):
    pass


class FirstLoanActionReadContract(NewUserActionReadContract):
    pass


class ActionDescriptionID(ID):
    _service = SERVICE
    _app = APP
    _view_set = 'action_description'


class NewUserActionID(ID):
    _service = SERVICE
    _app = APP
    _view_set = 'new_user_action'


class FirstLoanActionID(ID):
    _service = SERVICE
    _app = APP
    _view_set = 'first_loan_action'


class ActionDescriptionPoint(ListPointMixin, ContractPoint):
    _point_id = ActionDescriptionID()
    _read_contract = ActionDescriptionReadContract
    _sort_by = 'updated'


class NewUserActionPoint(ListPointMixin, CreatePointMixin, ContractPoint):
    _point_id = NewUserActionID()
    _create_contract = NewUserActionCreateContract
    _read_contract = NewUserActionReadContract
    _sort_by = 'created'


class FirstLoanActionPoint(ListPointMixin, CreatePointMixin, ContractPoint):
    _point_id = FirstLoanActionID()
    _create_contract = FirstLoanActionCreateContract
    _read_contract = FirstLoanActionReadContract
    _sort_by = 'created'



__all__ = ('ProfilePoint', 'UserProfilePoint')

from expressmoney.api import *

SERVICE = 'sync'


class ProfileReadContract(Contract):
    user_profile = serializers.IntegerField(min_value=1)
    created = serializers.DateTimeField(allow_null=True)


class UserProfileReadContract(Contract):
    created = serializers.DateTimeField()
    user_id = serializers.IntegerField(min_value=1)
    department = serializers.IntegerField(min_value=1)
    ip = serializers.IPAddressField()
    http_referer = serializers.URLField()
    country = serializers.CharField(max_length=2)


class ProfileID(ID):
    _service = SERVICE
    _app = 'profiles'
    _view_set = 'profile'


class UserProfileID(ID):
    _service = SERVICE
    _app = 'profiles'
    _view_set = 'user_profile'


class ProfilePoint(ListPointMixin, ContractPoint):
    _point_id = ProfileID()
    _read_contract = ProfileReadContract
    _sort_by = 'created'
    _cache_enabled = False


class UserProfilePoint(ListPointMixin, ContractPoint):
    _point_id = UserProfileID()
    _read_contract = UserProfileReadContract
    _sort_by = 'created'
    _cache_enabled = False
